===============
pyelasticsearch
===============

.. image:: https://travis-ci.org/rhec/pyelasticsearch.png
   :alt: Build Status
   :target: https://travis-ci.org/rhec/pyelasticsearch

pyelasticsearch is a clean, future-proof, high-scale API to elasticsearch. It
provides features like...

* Transparent conversion of Python data types to and from JSON
* Translating HTTP status codes representing failure into exceptions
* Connection pooling
* Load-balancing of requests across nodes in a cluster
* Failed-node marking to avoid downed nodes for a period
* Optional automatic retrying of failed requests

.. _`elasticsearch`: http://www.elasticsearch.org/

Full documentation: http://pyelasticsearch.readthedocs.org/
